package com.spring.series.orm.dao.impl;

import java.util.List;

import org.hibernate.SessionFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.spring.series.orm.dao.PlayerDAO;
import com.spring.series.orm.model.Player;

@Repository("playerDAO")
public class PlayerDAOImpl implements PlayerDAO {

	@Autowired
	private SessionFactory sessionFactory;

	public SessionFactory getSessionFactory() {
		return sessionFactory;
	}

	public void setSessionFactory(SessionFactory sessionFactory) {
		this.sessionFactory = sessionFactory;
	}

	/**
	 * create or inserts the new player information into the database using simpleJdbcTemplate
	 */
	@Transactional
	public String createOrSaveNewPLayer(Player player) {

		/*	Session session = getSessionFactory().openSession();
		Transaction tx = session.beginTransaction();
		session.save(player);
		tx.commit();
		session.close();*/

		int playerId = (Integer) getSessionFactory().getCurrentSession().save(player);
		return "Player information saved successfully with PLAYER_ID " + playerId;
	}

	/**
	 * This method retrieves a player from database using jdbcTemplate based on the PLAYER_ID supplied in the formal arguments
	 */
	@Transactional
	public Player getPlayer(int playerId) {

		Player player = (Player) getSessionFactory().getCurrentSession().get(Player.class, playerId);
		return player;
	}

	/**
	 * This method updates the player information in the database using simpleJdbcTemplate
	 */
	@Transactional
	public String updatePlayerInfo(Player player) {

		getSessionFactory().getCurrentSession().update(player);
		return "Player information updated successfully";
	}

	/**
	 * This method deletes the player information from the database using simpleJdbcTemplate
	 */
	@Transactional
	public String deletePlayerInfo(Player player) {

		getSessionFactory().getCurrentSession().delete(player);
		return "Player information deleted successfully";
	}

	/**
	 * Retrieves all players from the database using simpleJdbcTemplate
	 */
	@Transactional
	public List<Player> getAllPlayer() {

		return sessionFactory.getCurrentSession().createCriteria(Player.class).list();
	}
}